@@ -9,11 +9,11 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.KMS 1.17.101\n"
-        "Version:         1.17.101.post2\n"
-        "Builder version: 4.21.0\n"
+        "Type annotations for boto3.KMS 1.18.0\n"
+        "Version:         1.18.0\n"
+        "Builder version: 5.0.0\n"
         "Docs:            https://pypi.org/project/mypy-boto3-kms/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
@@ -23,7 +23,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.17.101.post2")
+    print("1.18.0")
 
 
 def main() -> None:
