@@ -16,7 +16,7 @@ import sys
 from datetime import datetime
 from typing import IO, Any, Dict, List, Type, Union, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
 
 from .literals import (
@@ -124,20 +124,25 @@ class Exceptions:
     UnsupportedOperationException: Type[BotocoreClientError]
 
 
-class KMSClient:
+class KMSClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        KMSClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#can_paginate)
         """
 
@@ -145,7 +150,7 @@ class KMSClient:
         """
         Cancels the deletion of a customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.cancel_key_deletion)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.cancel_key_deletion)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#cancel_key_deletion)
         """
 
@@ -155,7 +160,7 @@ class KMSClient:
         <https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-
         overview.html>`__ to its associated AWS CloudHSM cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.connect_custom_key_store)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.connect_custom_key_store)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#connect_custom_key_store)
         """
 
@@ -163,7 +168,7 @@ class KMSClient:
         """
         Creates a friendly name for a customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.create_alias)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.create_alias)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#create_alias)
         """
 
@@ -182,7 +187,7 @@ class KMSClient:
         <https://docs.aws.amazon.com/cloudhsm/latest/userguide/clusters.html>`__ that
         you own and manage.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.create_custom_key_store)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.create_custom_key_store)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#create_custom_key_store)
         """
 
@@ -200,7 +205,7 @@ class KMSClient:
         """
         Adds a grant to a customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.create_grant)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.create_grant)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#create_grant)
         """
 
@@ -222,7 +227,7 @@ class KMSClient:
         <https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#master-
         keys>`__ (CMK) in your AWS account and Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.create_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.create_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#create_key)
         """
 
@@ -241,7 +246,7 @@ class KMSClient:
         GenerateDataKeyPair *  GenerateDataKeyWithoutPlaintext *
         GenerateDataKeyPairWithoutPlaintext You can use this o...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.decrypt)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.decrypt)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#decrypt)
         """
 
@@ -249,7 +254,7 @@ class KMSClient:
         """
         Deletes the specified alias.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.delete_alias)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.delete_alias)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#delete_alias)
         """
 
@@ -259,7 +264,7 @@ class KMSClient:
         <https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-
         overview.html>`__.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.delete_custom_key_store)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.delete_custom_key_store)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#delete_custom_key_store)
         """
 
@@ -267,7 +272,7 @@ class KMSClient:
         """
         Deletes key material that you previously imported.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.delete_imported_key_material)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.delete_imported_key_material)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#delete_imported_key_material)
         """
 
@@ -284,7 +289,7 @@ class KMSClient:
         <https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-
         overview.html>`__ in the account and Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.describe_custom_key_stores)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.describe_custom_key_stores)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#describe_custom_key_stores)
         """
 
@@ -294,7 +299,7 @@ class KMSClient:
         """
         Provides detailed information about a customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.describe_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.describe_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#describe_key)
         """
 
@@ -302,7 +307,7 @@ class KMSClient:
         """
         Sets the state of a customer master key (CMK) to disabled.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.disable_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.disable_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#disable_key)
         """
 
@@ -312,7 +317,7 @@ class KMSClient:
         <https://docs.aws.amazon.com/kms/latest/developerguide/rotate-keys.html>`__ for
         the specified symmetric customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.disable_key_rotation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.disable_key_rotation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#disable_key_rotation)
         """
 
@@ -322,7 +327,7 @@ class KMSClient:
         <https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-
         overview.html>`__ from its associated AWS CloudHSM cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.disconnect_custom_key_store)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.disconnect_custom_key_store)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#disconnect_custom_key_store)
         """
 
@@ -330,7 +335,7 @@ class KMSClient:
         """
         Sets the key state of a customer master key (CMK) to enabled.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.enable_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.enable_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#enable_key)
         """
 
@@ -340,7 +345,7 @@ class KMSClient:
         <https://docs.aws.amazon.com/kms/latest/developerguide/rotate-keys.html>`__ for
         the specified symmetric customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.enable_key_rotation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.enable_key_rotation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#enable_key_rotation)
         """
 
@@ -356,7 +361,7 @@ class KMSClient:
         """
         Encrypts plaintext into ciphertext by using a customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.encrypt)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.encrypt)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#encrypt)
         """
 
@@ -372,7 +377,7 @@ class KMSClient:
         """
         Generates a unique symmetric data key for client-side encryption.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.generate_data_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.generate_data_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#generate_data_key)
         """
 
@@ -387,7 +392,7 @@ class KMSClient:
         """
         Generates a unique asymmetric data key pair.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.generate_data_key_pair)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.generate_data_key_pair)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#generate_data_key_pair)
         """
 
@@ -402,7 +407,7 @@ class KMSClient:
         """
         Generates a unique asymmetric data key pair.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.generate_data_key_pair_without_plaintext)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.generate_data_key_pair_without_plaintext)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#generate_data_key_pair_without_plaintext)
         """
 
@@ -418,7 +423,7 @@ class KMSClient:
         """
         Generates a unique symmetric data key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.generate_data_key_without_plaintext)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.generate_data_key_without_plaintext)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#generate_data_key_without_plaintext)
         """
 
@@ -432,7 +437,7 @@ class KMSClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#generate_presigned_url)
         """
 
@@ -442,7 +447,7 @@ class KMSClient:
         """
         Returns a random byte string that is cryptographically secure.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.generate_random)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.generate_random)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#generate_random)
         """
 
@@ -450,7 +455,7 @@ class KMSClient:
         """
         Gets a key policy attached to the specified customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.get_key_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.get_key_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#get_key_policy)
         """
 
@@ -460,7 +465,7 @@ class KMSClient:
         material <https://docs.aws.amazon.com/kms/latest/developerguide/rotate-
         keys.html>`__ is enabled for the specified customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.get_key_rotation_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.get_key_rotation_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#get_key_rotation_status)
         """
 
@@ -475,7 +480,7 @@ class KMSClient:
         Returns the items you need to import key material into a symmetric, customer
         managed customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.get_parameters_for_import)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.get_parameters_for_import)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#get_parameters_for_import)
         """
 
@@ -485,7 +490,7 @@ class KMSClient:
         """
         Returns the public key of an asymmetric CMK.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.get_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.get_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#get_public_key)
         """
 
@@ -502,7 +507,7 @@ class KMSClient:
         Imports key material into an existing symmetric AWS KMS customer master key
         (CMK) that was created without key material.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.import_key_material)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.import_key_material)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#import_key_material)
         """
 
@@ -512,7 +517,7 @@ class KMSClient:
         """
         Gets a list of aliases in the caller's AWS account and region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.list_aliases)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.list_aliases)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#list_aliases)
         """
 
@@ -528,7 +533,7 @@ class KMSClient:
         """
         Gets a list of all grants for the specified customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.list_grants)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.list_grants)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#list_grants)
         """
 
@@ -539,7 +544,7 @@ class KMSClient:
         Gets the names of the key policies that are attached to a customer master key
         (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.list_key_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.list_key_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#list_key_policies)
         """
 
@@ -548,7 +553,7 @@ class KMSClient:
         Gets a list of all customer master keys (CMKs) in the caller's AWS account and
         Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.list_keys)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.list_keys)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#list_keys)
         """
 
@@ -558,7 +563,7 @@ class KMSClient:
         """
         Returns all tags on the specified customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.list_resource_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.list_resource_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#list_resource_tags)
         """
 
@@ -569,7 +574,7 @@ class KMSClient:
         Returns information about all grants in the AWS account and Region that have the
         specified retiring principal.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.list_retirable_grants)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.list_retirable_grants)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#list_retirable_grants)
         """
 
@@ -584,7 +589,7 @@ class KMSClient:
         """
         Attaches a key policy to the specified customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.put_key_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.put_key_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#put_key_policy)
         """
 
@@ -603,7 +608,7 @@ class KMSClient:
         """
         Decrypts ciphertext and then reencrypts it entirely within AWS KMS.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.re_encrypt)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.re_encrypt)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#re_encrypt)
         """
 
@@ -620,7 +625,7 @@ class KMSClient:
         """
         Replicates a multi-Region key into the specified Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.replicate_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.replicate_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#replicate_key)
         """
 
@@ -630,7 +635,7 @@ class KMSClient:
         """
         Deletes a grant.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.retire_grant)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.retire_grant)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#retire_grant)
         """
 
@@ -638,7 +643,7 @@ class KMSClient:
         """
         Deletes the specified grant.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.revoke_grant)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.revoke_grant)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#revoke_grant)
         """
 
@@ -648,7 +653,7 @@ class KMSClient:
         """
         Schedules the deletion of a customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.schedule_key_deletion)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.schedule_key_deletion)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#schedule_key_deletion)
         """
 
@@ -666,7 +671,7 @@ class KMSClient:
         <https://en.wikipedia.org/wiki/Digital_signature>`__ for a message or message
         digest by using the private key in an asymmetric CMK.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.sign)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.sign)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#sign)
         """
 
@@ -676,7 +681,7 @@ class KMSClient:
         <https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#customer-
         cmk>`__ .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#tag_resource)
         """
 
@@ -686,7 +691,7 @@ class KMSClient:
         <https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#customer-
         cmk>`__.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#untag_resource)
         """
 
@@ -694,7 +699,7 @@ class KMSClient:
         """
         Associates an existing AWS KMS alias with a different customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.update_alias)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.update_alias)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#update_alias)
         """
 
@@ -709,7 +714,7 @@ class KMSClient:
         """
         Changes the properties of a custom key store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.update_custom_key_store)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.update_custom_key_store)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#update_custom_key_store)
         """
 
@@ -717,7 +722,7 @@ class KMSClient:
         """
         Updates the description of a customer master key (CMK).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.update_key_description)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.update_key_description)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#update_key_description)
         """
 
@@ -725,7 +730,7 @@ class KMSClient:
         """
         Changes the primary key of a multi-Region key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.update_primary_region)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.update_primary_region)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#update_primary_region)
         """
 
@@ -742,21 +747,21 @@ class KMSClient:
         """
         Verifies a digital signature that was generated by the  Sign operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Client.verify)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Client.verify)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#verify)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_aliases"]) -> ListAliasesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Paginator.ListAliases)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Paginator.ListAliases)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/paginators.html#listaliasespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_grants"]) -> ListGrantsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Paginator.ListGrants)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Paginator.ListGrants)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/paginators.html#listgrantspaginator)
         """
 
@@ -765,13 +770,13 @@ class KMSClient:
         self, operation_name: Literal["list_key_policies"]
     ) -> ListKeyPoliciesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Paginator.ListKeyPolicies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Paginator.ListKeyPolicies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/paginators.html#listkeypoliciespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_keys"]) -> ListKeysPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kms.html#KMS.Paginator.ListKeys)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/kms.html#KMS.Paginator.ListKeys)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/paginators.html#listkeyspaginator)
         """
